@@ -3,10 +3,11 @@ from typing import Dict
 import pandas as pd
 import textwrap
 
+
 def replace_unescaped_pipes(text: str) -> str:
     """
     Replace unescaped pipes.
-    
+
     For regex explanation, see https://regex101.com/r/s8H588/1
 
     Args:
@@ -24,20 +25,24 @@ def convert_to_md_table(df: pd.DataFrame, markdown_kwargs: Dict) -> str:
     """
     # Escape any pipe characters, | to \|
     # See https://github.com/astanin/python-tabulate/issues/241
-    df.columns = [replace_unescaped_pipes(c) if isinstance(c, str) else c for c in df.columns]
+    df.columns = [
+        replace_unescaped_pipes(c) if isinstance(c, str) else c for c in df.columns
+    ]
 
     # Avoid deprecated applymap warning on pandas>=2.0
     # See https://github.com/timvink/mkdocs-table-reader-plugin/issues/55
     if pd.__version__ >= "2.1.0":
         df = df.map(lambda s: replace_unescaped_pipes(s) if isinstance(s, str) else s)
     else:
-        df = df.applymap(lambda s: replace_unescaped_pipes(s) if isinstance(s, str) else s)
+        df = df.applymap(
+            lambda s: replace_unescaped_pipes(s) if isinstance(s, str) else s
+        )
 
     if "index" not in markdown_kwargs:
         markdown_kwargs["index"] = False
     if "tablefmt" not in markdown_kwargs:
         markdown_kwargs["tablefmt"] = "pipe"
-    
+
     return df.to_markdown(**markdown_kwargs)
 
 
@@ -56,7 +61,7 @@ def fix_indentation(leading_spaces: str, text: str) -> str:
     leading_spaces = int(len(leading_spaces) / 4) * "    "
 
     fixed_lines = []
-    for line in text.split('\n'):
+    for line in text.split("\n"):
         fixed_lines.append(textwrap.indent(line, leading_spaces))
     text = "\n".join(fixed_lines)
     return text
